macro_rules! info_if {
{ $verbose:expr, $($arg:tt)* } => { ... };
}Expand description
Logging in the medium verbosity level (warn < info < debug), if the expression in the first argument evaluates to true
macro_rules! info_if {
{ $verbose:expr, $($arg:tt)* } => { ... };
}Logging in the medium verbosity level (warn < info < debug), if the expression in the first argument evaluates to true