macro_rules! lazy {
{ move $($body:tt)* } => { ... };
{ $($body:tt)* } => { ... };
}Expand description
Construct a value lazily (for expressions that return Result,
use lazyresult) (Todo: update to not require &mut)
Construct a Lazy value that runs the code body given to the
macro once on the first call to force. Moves the captured values
if a move keyword is given as the first item in the body. If the
body evaluates to a Result, better use lazyresult! instead
because Result is generally not cloneable and thus force()?
won’t work.